<?php
/*----------------------------------------------------------------------------
 * mstw-tr-data-fields-columns-settings.php
 *	All functions for the MSTW Team Rosters Plugin's data fields & columns settings.
 *	Loaded by mstw-tr-settings.php 
 *
 *	MSTW Wordpress Plugins (http://shoalsummitsolutions.com)
 *	Copyright 2014-25 Mark O'Donnell (mark@shoalsummitsolutions.com)
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.

 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program. If not, see <http://www.gnu.org/licenses/>.
 *--------------------------------------------------------------------------*/

//-----------------------------------------------------------------	
// 	This first function is here for potential future page re-org	
//		
	function mstw_tr_data_fields_setup( ) {
		//mstw_log_msg( 'mstw_tr_data_fields_setup:' );
		mstw_tr_data_fields_left_setup( );
		mstw_tr_data_fields_center_setup( );
		mstw_tr_data_fields_right_setup( );
	}
	
	function mstw_tr_data_fields_left_setup( ) {
		//mstw_log_msg( 'mstw_tr_data_fields_left_setup:' );	
		
		$options = wp_parse_args( get_option( 'mstw_tr_options' ), mstw_tr_get_defaults( ) );
		
		// Roster Table data fields/columns -- show/hide and labels
		
		$display_on_page   = 'mstw-tr-data-fields-labels';
		$page_section      = 'mstw-tr-fields-labels';
		$instruct_callback = null;
		$section_title     = __( 'Data Fields Labels', 'team-rosters' );
		
		add_settings_section( $page_section, 
													$section_title, 
													$instruct_callback, 
													$display_on_page );

		$arguments = array(
			
			array( 	// Player PHOTO LABEL
				'type' => 'text', 
				'id' => 'photo_label',
				'name'	=> 'mstw_tr_options[photo_label]',
				'value' => mstw_tr_safe_ref( $options, 'photo_label' ), 
				'title' => __( 'Photo Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Photo)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// NAME column label
				'type' => 'text', 
				'id' => 'name_label',
				'name'	=> 'mstw_tr_options[name_label]',
				'value' => mstw_tr_safe_ref( $options, 'name_label' ), 
				'title' => __( 'Name Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Name)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// NUMBER column label
				'type' => 'text', 
				'id' => 'number_label',
				'name'	=> 'mstw_tr_options[number_label]',
				'value' => mstw_tr_safe_ref( $options, 'number_label' ),
				'title'	=> __( 'Number Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Nbr)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// POSITION column label
				'type' => 'text', 
				'id' => 'position_label',
				'name'	=> 'mstw_tr_options[position_label]',
				'value' => mstw_tr_safe_ref( $options, 'position_label' ),
				'title'	=> __( 'Position Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Pos)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// HEIGHT column label
				'type' => 'text', 
				'id' => 'height_label',
				'name'	=> 'mstw_tr_options[height_label]',
				'value' => mstw_tr_safe_ref( $options, 'height_label' ),
				'title'	=> __( 'Height Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Ht)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// WEIGHT column label
				'type' => 'text', 
				'id' => 'weight_label',
				'name'	=> 'mstw_tr_options[weight_label]',
				'value' => mstw_tr_safe_ref( $options, 'weight_label' ),
				'title'	=> __( 'Weight Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Wt)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
		
			array( 	// YEAR column label
				'type' => 'text', 
				'id' => 'year_label',
				'name'	=> 'mstw_tr_options[year_label]',
				'value' => mstw_tr_safe_ref( $options, 'year_label' ),
				'title'	=> __( 'Year Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Year)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// EXPERIENCE column label
				'type' => 'text', 
				'id' => 'experience_label',
				'name'	=> 'mstw_tr_options[experience_label]',
				'value' => mstw_tr_safe_ref( $options, 'experience_label' ),
				'title'	=> __( 'Experience Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Exp)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// AGE column label
				'type' => 'text', 
				'id' => 'age_label',
				'name'	=> 'mstw_tr_options[age_label]',
				'value' => mstw_tr_safe_ref( $options, 'age_label' ),
				'title'	=> __( 'Age Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Age)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// HOME TOWN column label
				'type' => 'text', 
				'id' => 'home_town_label',
				'name'	=> 'mstw_tr_options[home_town_label]',
				'value' => mstw_tr_safe_ref( $options, 'home_town_label' ),
				'title'	=> __( 'Home Town Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Home Town)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// LAST SCHOOL column label
				'type' => 'text', 
				'id' => 'last_school_label',
				'name'	=> 'mstw_tr_options[last_school_label]',
				'value' => mstw_tr_safe_ref( $options, 'last_school_label' ),
				'title'	=> __( 'Last School Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Last School)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// COUNTRY column label
				'type' => 'text', 
				'id' => 'country_label',
				'name'	=> 'mstw_tr_options[country_label]',
				'value' => mstw_tr_safe_ref( $options, 'country_label' ),
				'title'	=> __( 'Country Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Country)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// BATS/THROWS column label
				'type' => 'text', 
				'id' => 'bats_throws_label',
				'name'	=> 'mstw_tr_options[bats_throws_label]',
				'value' => mstw_tr_safe_ref( $options, 'bats_throws_label' ),
				'title'	=> __( 'Bats/Throws Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Bat/Thw)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// OTHER INFO column label
				'type' => 'text', 
				'id' => 'other_info_label',
				'name'	=> 'mstw_tr_options[other_info_label]',
				'value' => mstw_tr_safe_ref( $options, 'other_info_label' ),
				'title'	=> __( 'Other Info Label:', 'team-rosters' ),
				'desc'	=> __( '(Default: Other)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
		);
		
		mstw_tr_build_settings_screen( $arguments );
		
	} //End: mstw_tr_data_fields_left_setup() 
	
	function mstw_tr_data_fields_center_setup( ) {
		//mstw_log_msg( 'mstw_tr_data_fields_center_setup:' );	
		
		$options = wp_parse_args( get_option( 'mstw_tr_options' ), mstw_tr_get_defaults( ) );
		
		
		// Roster Table data fields/columns -- show/hide
		
		$display_on_page   = 'mstw-tr-fields-show-hide';
		$page_section      = 'mstw-tr-fields-show-hide';
		$instruct_callback = null;
		$section_title     = __( 'Visibility', 'team-rosters' );
		
		add_settings_section( $page_section, 
													$section_title, 
													$instruct_callback, 
													$display_on_page );
		
		$arguments = array(
			array( 	// Show/hide player PHOTOS
				'type' => 'show-hide', 
				'id' => 'show_photos',
				'name'	=> 'mstw_tr_options[show_photos]',
				'value' => mstw_safe_get( 'show_photos', $options, 0 ), 
				'title'	=> null,
				'desc'	=> __( '(Default: Hide)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Show/hide NAME column
				'type' => 'show-hide', 
				'id' => 'show_name',
				'name'	=> 'mstw_tr_options[show_name]',
				'value' => 1, //mstw_tr_safe_ref( $options, 'show_number' ), 
				'title' => null,
				'desc'	=> __( '(Always shown.)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Show/hide NUMBER column
				'type' => 'show-hide', 
				'id' => 'show_number',
				'name'	=> 'mstw_tr_options[show_number]',
				'value' => mstw_tr_safe_ref( $options, 'show_number' ), 
				'title' => null,
				'desc'	=> __( '(Default: Show)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Show/hide POSITION column
				'type' => 'show-hide', 
				'id' => 'show_position',
				'name'	=> 'mstw_tr_options[show_position]',
				'value' => mstw_tr_safe_ref( $options, 'show_position' ), 
				'title' => null,
				'desc'	=> __( '(Default: Show)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Show/hide HEIGHT column
				'type' => 'show-hide', 
				'id' => 'show_height',
				'name'	=> 'mstw_tr_options[show_height]',
				'value' => mstw_tr_safe_ref( $options, 'show_height' ), 
				'title'	=> null,
				'desc'	=> __( '(Default: Show)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Show/hide WEIGHT column
				'type' => 'show-hide', 
				'id' => 'show_weight',
				'name'	=> 'mstw_tr_options[show_weight]',
				'value' => mstw_tr_safe_ref( $options, 'show_weight' ), 
				'title'	=> null,
				'desc'	=> __( '(Default: Show)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Show/hide YEAR column
				'type' => 'show-hide', 
				'id' => 'show_year',
				'name'	=> 'mstw_tr_options[show_year]',
				'value' => mstw_tr_safe_ref( $options, 'show_year' ), 
				'title'	=> null,
				'desc'	=> __( '(Default: Hide)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Show/hide EXPERIENCE column
				'type' => 'show-hide', 
				'id' => 'show_experience',
				'name'	=> 'mstw_tr_options[show_experience]',
				'value' => mstw_tr_safe_ref( $options, 'show_experience' ), 
				'title'	=> null,
				'desc'	=> __( '(Default: Hide)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Show/hide AGE column
				'type' => 'show-hide', 
				'id' => 'show_age',
				'name'	=> 'mstw_tr_options[show_age]',
				'value' => mstw_tr_safe_ref( $options, 'show_age' ), 
				'title'	=> null,
				'desc'	=> __( '(Default: Hide)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Show/hide HOME TOWN column
				'type' => 'show-hide', 
				'id' => 'show_home_town',
				'name'	=> 'mstw_tr_options[show_home_town]',
				'value' => mstw_tr_safe_ref( $options, 'show_home_town' ), 
				'title'	=> null,
				'desc' =>	__( '(Default: Hide)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Show/hide LAST SCHOOL column
				'type' => 'show-hide', 
				'id' => 'show_last_school',
				'name'	=> 'mstw_tr_options[show_last_school]',
				'value' => mstw_tr_safe_ref( $options, 'show_last_school' ), 
				'title'	=> null,
				'desc'	=> __( '(Default: Hide)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Show/hide COUNTRY column
				'type' => 'show-hide', 
				'id' => 'show_country',
				'name'	=> 'mstw_tr_options[show_country]',
				'value' => mstw_tr_safe_ref( $options, 'show_country' ), 
				'title'	=> null,
				'desc'	=> __( '(Default: Hide)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Show/hide BATS/THROWS column
				'type' => 'show-hide', 
				'id' => 'show_bats_throws',
				'name'	=> 'mstw_tr_options[show_bats_throws]',
				'value' => mstw_tr_safe_ref( $options, 'show_bats_throws' ), 
				'title'	=> null,
				'desc'	=> __( '(Default: Hide)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Show/hide OTHER INFO column
				'type' => 'show-hide', 
				'id' => 'show_other_info',
				'name'	=> 'mstw_tr_options[show_other_info]',
				'value' => mstw_tr_safe_ref( $options, 'show_other_info' ), 
				'title'	=> null,
				'desc'	=> __( '(Default: Hide)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
		);
		
		mstw_tr_build_settings_screen( $arguments );
		
	} //End: mstw_tr_data_fields_center_setup()

	function mstw_tr_data_fields_right_setup( ) {
		//mstw_log_msg( 'mstw_tr_data_fields_right_setup:' );	
	
		$options = wp_parse_args( get_option( 'mstw_tr_options' ), mstw_tr_get_defaults( ) );
		
		
		// Roster Table data fields/columns -- order
		$display_on_page   = 'mstw-tr-fields-order';
		$page_section      = 'mstw-tr-fields-order';
		$instruct_callback = null;
		$section_title     = __( 'Order', 'team-rosters' );
		
		add_settings_section( $page_section, 
													$section_title, 
													$instruct_callback, 
													$display_on_page );

		$arguments = array(
			array( 	//Order player PHOTOS
				'type' => 'text', 
				'id' => 'order_photo',
				'name'	=> 'mstw_tr_options[order_photo]',
				'value' => mstw_safe_get( 'order_photo', $options, 1 ), 
				'title'	=> null,
				'desc'	=> __( '(Default: 1)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	//Order NAME column
				'type' => 'text', 
				'id' => 'order_name',
				'name'	=> 'mstw_tr_options[order_name]',
				'value' => mstw_safe_get( 'order_name', $options, 2 ), 
				'title' => null,
				'desc'	=> __( '(Default: 2)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	//Order NUMBER column
				'type' => 'text', 
				'id' => 'order_number',
				'name'	=> 'mstw_tr_options[order_number]',
				'value' => mstw_safe_get( 'order_number', $options, 3 ), 
				'title' => null,
				'desc'	=> __( '(Default: 3)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	//Order POSITION column
				'type' => 'text', 
				'id' => 'order_position',
				'name'	=> 'mstw_tr_options[order_position]',
				'value' => mstw_safe_get( 'order_position', $options, 4 ), 
				'title' => null,
				'desc'	=> __( '(Default: 4)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	//Order HEIGHT column
				'type' => 'text', 
				'id' => 'order_height',
				'name'	=> 'mstw_tr_options[order_height]',
				'value' => mstw_safe_get( 'order_height', $options, 5 ), 
				'title'	=> null,
				'desc'	=> __( '(Default: 5)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	//Order WEIGHT column
				'type' => 'text', 
				'id' => 'order_weight',
				'name'	=> 'mstw_tr_options[order_weight]',
				'value' => mstw_safe_get( 'order_weight', $options, 6 ), 
				'title'	=> null,
				'desc'	=> __( '(Default: 6)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	//Order YEAR column
				'type' => 'text', 
				'id' => 'order_year',
				'name'	=> 'mstw_tr_options[order_year]',
				'value' => mstw_safe_get( 'order_year', $options, 7 ), 
				'title'	=> null,
				'desc'	=> __( '(Default: 7)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	//Order EXPERIENCE column
				'type' => 'text', 
				'id' => 'order_experience',
				'name'	=> 'mstw_tr_options[order_experience]',
				'value' => mstw_safe_get( 'order_experience', $options, 8 ), 
				'title'	=> null,
				'desc'	=> __( '(Default: 8)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	//Order AGE column
				'type' => 'text', 
				'id' => 'order_age',
				'name'	=> 'mstw_tr_options[order_age]',
				'value' => mstw_safe_get( 'order_age', $options, 9 ),
				'title'	=> null,
				'desc'	=> __( '(Default: 9)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	//Order HOME TOWN column
				'type' => 'text', 
				'id' => 'order_home_town',
				'name'	=> 'mstw_tr_options[order_home_town]',
				'value' => mstw_safe_get( 'order_home_town', $options, 10 ),
				'title'	=> null,
				'desc' =>	__( '(Default: 10)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	//Order LAST SCHOOL column
				'type' => 'text', 
				'id' => 'order_last_school',
				'name'	=> 'mstw_tr_options[order_last_school]',
				'value' => mstw_safe_get( 'order_last_school', $options, 11 ),
				'title'	=> null,
				'desc'	=> __( '(Default: 11)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	//Order COUNTRY column
				'type' => 'text', 
				'id' => 'order_country',
				'name'	=> 'mstw_tr_options[order_country]',
				'value' => mstw_safe_get( 'order_country', $options, 12 ), 
				'title'	=> null,
				'desc'	=> __( '(Default: 12)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	//Order BATS/THROWS column
				'type' => 'text', 
				'id' => 'order_bats_throws',
				'name'	=> 'mstw_tr_options[order_bats_throws]',
				'value' => mstw_safe_get( 'order_bats_throws', $options, 13 ), 
				'title'	=> null,
				'desc'	=> __( '(Default: 13)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
			array( 	// Order OTHER INFO column
				'type' => 'text', 
				'id' => 'order_other_info',
				'name'	=> 'mstw_tr_options[order_other_info]',
				'value' => mstw_safe_get( 'order_other_info', $options, 14 ), 
				'title'	=> null,
				'desc'	=> __( '(Default: 14)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $page_section,
			),
			
		);
		
		mstw_tr_build_settings_screen( $arguments );
		
	} //End: mstw_tr_data_fields_right_setup()