<?php
/*----------------------------------------------------------------------------
 * mstw-tr-roster-table-settings.php
 *	All functions for the MSTW Team Rosters Plugin's roster table [shortcode] settings.
 *	Loaded in mstw-tr-settings.php 
 *
 *	MSTW Wordpress Plugins (http://shoalsummitsolutions.com)
 *	Copyright 2014-25 Mark O'Donnell (mark@shoalsummitsolutions.com)
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.

 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program. If not, see <http://www.gnu.org/licenses/>.
 *--------------------------------------------------------------------------*/

	function mstw_tr_roster_table_setup( ) {
		//mstw_log_msg( 'mstw_tr_roster_table_setup:' );
		
		$options = wp_parse_args( get_option( 'mstw_tr_options' ), 
		array_merge( mstw_tr_get_roster_table_defaults( ), mstw_tr_get_roster_table2_defaults( ) ) );
		
		mstw_tr_roster_table_section_setup( $options );
		mstw_tr_roster_table2_section_setup( $options );

	} //End: mstw_tr_roster_colors_setup()		

	function mstw_tr_roster_table_section_setup( $options ) {
		//mstw_log_msg( 'mstw_tr_roster_table_section_setup:' );
		
		// Roster Table data fields/columns -- show/hide and labels
		$display_on_page = 'mstw-tr-roster-table';
		$section_id = 'mstw-tr-roster-table-settings'; //'mstw_tr_table_structure_settings';
		$instruct_callback = 'mstw_tr_roster_table_inst';
		$section_title = __( 'Roster Table Settings', 'team-rosters' );
		
		add_settings_section( $section_id, 
													$section_title, 
													$instruct_callback, 
													$display_on_page );

		$arguments = array(
			array( 	// Show/hide roster TITLE
				'type' => 'show-hide', 
				'id' => 'show_title',
				'name'	=> 'mstw_tr_options[show_title]',
				'value' => mstw_tr_safe_ref( $options, 'show_title', 0 ), 
				'title' => __( 'Show Roster Table Titles:', 'team-rosters' ),
				'desc'	=> __( 'Titles will display as "Team Name Roster" (Default: Hide)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			array( 	// Roster FORMAT
				'type' => 'select-option', 
				'id' => 'roster_type',
				'name'	=> 'mstw_tr_options[roster_type]',
				'value' => mstw_tr_safe_ref( $options, 'roster_type' ),
				'options' => array(	__( 'Custom', 'team-rosters' )=> 'custom', 
										__( 'Pro', 'team-rosters' ) => 'pro', 
										__( 'College', 'team-rosters' ) => 'college',
										__( 'High School', 'team-rosters' ) => 'high-school',
										__( 'Pro Baseball', 'team-rosters' ) => 'baseball-pro', 
										__( 'College Baseball', 'team-rosters' ) => 'baseball-college',
										__( 'High School Baseball', 'team-rosters' ) => 'baseball-high-school',
										),
				'title'	=> __( 'Roster Table Format:', 'team-rosters' ),
				'desc'	=> __( 'Default: Custom, which is what you want if you are customizing the columns in the Data Fields & Columns tab.', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			array( 	// ADD LINKS TO PROFILES
				'type' => 'checkbox', 
				'id' => 'links_to_profiles',
				'name'	=> 'mstw_tr_options[links_to_profiles]',
				'value' => mstw_tr_safe_ref( $options, 'links_to_profiles' ), 
				'title' => __( 'Add Links to Player Profiles:', 'team-rosters' ),
				'desc'	=> __( 'This setting applies to both roster tables and player galleries. Default: No Links (Unchecked)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			array( 	// SORT BY FIELD
				'type' => 'select-option', 
				'id' => 'sort_order',
				'name'	=> 'mstw_tr_options[sort_order]',
				'value' => mstw_tr_safe_ref( $options, 'sort_order' ), 
				'options' => array(	__( 'Last Name', 'team-rosters' )=> 'alpha', 
									__( 'First Name', 'team-rosters' ) => 'alpha-first', 
									__( 'Number', 'team-rosters' ) => 'numeric'		
									),
				'title' => __( 'Sort Roster By:', 'team-rosters' ),
				'desc'	=> __( 'Default: Last Name', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			array( 	// SORT ORDER
				'type' => 'select-option', 
				'id' => 'sort_asc_desc',
				'name'	=> 'mstw_tr_options[sort_asc_desc]',
				'value' => mstw_tr_safe_ref( $options, 'sort_asc_desc' ), 
				'options' => array(	__( 'Ascending', 'team-rosters' )=> 'asc', 
									__( 'Descending', 'team-rosters' ) => 'desc'		
									),
				'title' => __( 'Sort Order:', 'team-rosters' ),
				'desc'	=> __( 'Default: Ascending (1, 2, 3 ... or a, b, c ...)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			array( 	// DISPLAY FORMAT for Player Names
				'type' => 'select-option', 
				'id' => 'name_format',
				'name'	=> 'mstw_tr_options[name_format]',
				'value' => mstw_tr_safe_ref( $options, 'name_format' ), 
				'options' => array(	__( 'Last, First', 'team-rosters' )=> 'last-first', 
									__( 'First Last', 'team-rosters' ) => 'first-last', 
									__( 'First Name Only', 'team-rosters' ) => 'first-only',
									__( 'Last Name Only', 'team-rosters' ) => 'last-only'		
									),
				'title' => __( 'Display Players By:', 'team-rosters' ),
				'desc'	=> __( 'Default: Last, First', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
		
			array( 	// Player PHOTO WIDTH
				'type' => 'text', 
				'id' => 'table_photo_width',
				'name'	=> 'mstw_tr_options[table_photo_width]',
				'value' => mstw_tr_safe_ref( $options, 'table_photo_width' ), 
				'title' => __( 'Table Photo Width:', 'team-rosters' ),
				'desc'	=> __( 'In pixels. (Defaults to blank, which means the stylesheet setting will be used; 64px out of the box.)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			array( 	// Player PHOTO HEIGHT
				'type' => 'text', 
				'id' => 'table_photo_height',
				'name'	=> 'mstw_tr_options[table_photo_height]',
				'value' => mstw_tr_safe_ref( $options, 'table_photo_height' ), 
				'title' => __( 'Table Photo Height:', 'team-rosters' ),
				'desc'	=> __( 'In pixels. (Defaults to blank, which means the stylesheet setting will be used; 64px out of the box.)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			
		);
		
		mstw_tr_build_settings_screen( $arguments );
		
	} //End: mstw_tr_roster_table_section_setup( )

	function mstw_tr_roster_table2_section_setup( $options ) {
		//mstw_log_msg( 'mstw_tr_roster_table2_section_setup:' );
		
		$dataFields = array(  __( 'Height Only', 'team-rosters' ) => 'height',
													__( 'Height/Weight', 'team-rosters' )	=> 'height-weight',
													__( 'Bats/Throws', 'team-rosters' )	=> 'bats-throws',
													__( 'Class/Year', 'team-rosters' ) => 'year-short',
													__( 'Class/Year (long format)', 'team-rosters' ) => 'year-long',
													__( 'Experience', 'team-rosters' ) => 'experience',
													__( 'Age', 'team-rosters' ) => 'age',
													__( 'Home Town', 'team-rosters' ) => 'home-town',
													__( 'Last School', 'team-rosters' ) => 'last-school',
													__( 'Country', 'team-rosters' ) => 'country',
													__( 'Bats/Throws', 'team-rosters' ) => 'bats-throws',
													__( 'Other Info', 'team-rosters' ) => 'other-info',						
												);
		
		// Roster Table data fields/columns -- show/hide and labels
		$display_on_page = 'mstw-tr-roster2-table';
		$section_id = 'mstw-tr-roster-table2-settings'; //'mstw_tr_table_2_structure_settings';
		$instruct_callback = 'mstw_tr_roster_table_2_inst';
		$section_title = __( 'Roster Table 2 Settings', 'team-rosters' );
		
		add_settings_section( $section_id, 
													$section_title, 
													$instruct_callback, 
													$display_on_page );

		$arguments = array(
			array( 	// Show/hide roster TITLE
				'type' => 'show-hide', 
				'id' => 'show_title_2',
				'name'	=> 'mstw_tr_options[show_title_2]',
				'value' => mstw_tr_safe_ref( $options, 'show_title_2' ), 
				'title' => __( 'Show Titles for Roster Table 2:', 'team-rosters' ),
				'desc'	=> __( 'Titles will display as "Team Name Roster" (Default: Hide)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			array( 	// Roster FORMAT
				'type' => 'select-option', 
				'id' => 'roster_type_2',
				'name'	=> 'mstw_tr_options[roster_type_2]',
				'value' => mstw_tr_safe_ref( $options, 'roster_type_2' ),
				'options' => array(	__( 'Custom', 'team-rosters' )=> 'custom', 
										__( 'Pro', 'team-rosters' ) => 'pro', 
										__( 'College', 'team-rosters' ) => 'college',
										__( 'High School', 'team-rosters' ) => 'high-school',
										__( 'Pro Baseball', 'team-rosters' ) => 'baseball-pro', 
										__( 'College Baseball', 'team-rosters' ) => 'baseball-college',
										__( 'High School Baseball', 'team-rosters' ) => 'baseball-high-school',
										),
				'title'	=> __( 'Roster Table Format:', 'team-rosters' ),
				'desc'	=> __( 'This setting has no affect on the shortcode display. It ONLY affects the player bios linked from the shortcode roster.', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			array( 	// SORT BY FIELD
				'type' => 'select-option', 
				'id' => 'sort_order_2',
				'name'	=> 'mstw_tr_options[sort_order_2]',
				'value' => mstw_tr_safe_ref( $options, 'sort_order_2' ), 
				'options' => array(	__( 'Last Name', 'team-rosters' )=> 'alpha', 
									__( 'First Name', 'team-rosters' ) => 'alpha-first', 
									__( 'Number', 'team-rosters' ) => 'numeric'		
									),
				'title' => __( 'Sort Roster By:', 'team-rosters' ),
				'desc'	=> __( 'This setting is for the initial sort only. The user interface provides a control for sorting.', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			array( 	// SORT ORDER
				'type' => 'select-option', 
				'id' => 'sort_asc_desc_2',
				'name'	=> 'mstw_tr_options[sort_asc_desc_2]',
				'value' => mstw_tr_safe_ref( $options, 'sort_asc_desc_2' ),
				'options' => array(	__( 'Ascending', 'team-rosters' )=> 'asc', 
									__( 'Descending', 'team-rosters' ) => 'desc'		
									),
				'title' => __( 'Sort Order:', 'team-rosters' ),
				'desc'	=> __( 'Default: Ascending (1, 2, 3 ... or a, b, c ...)', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			array( 	// DISPLAY FORMAT for Player Names
				'type' => 'select-option', 
				'id' => 'name_format_2',
				'name'	=> 'mstw_tr_options[name_format_2]',
				'value' => mstw_tr_safe_ref( $options, 'name_format_2' ), 
				'options' => array(	__( 'Last, First', 'team-rosters' )=> 'last-first', 
									__( 'First Last', 'team-rosters' ) => 'first-last', 
									__( 'First Name Only', 'team-rosters' ) => 'first-only',
									__( 'Last Name Only', 'team-rosters' ) => 'last-only'		
									),
				'title' => __( 'Display Players By:', 'team-rosters' ),
				'desc'	=> __( 'Default: First Last', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			array( 	// FIRST/LEFTMOST DATA FIELD
				'type' => 'select-option', 
				'id' => 'data_field_1',
				'name'	=> 'mstw_tr_options[data_field_1]',
				'value' => mstw_tr_safe_ref( $options, 'data_field_1' ), 
				'options' => $dataFields,
				'title' => __( 'First(leftmost) Data Field:', 'team-rosters' ),
				'desc'	=> __( 'Default: Class/year', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			array( 	// Second/center data field
				'type' => 'select-option', 
				'id' => 'data_field_2',
				'name'	=> 'mstw_tr_options[data_field_2]',
				'value' => mstw_tr_safe_ref( $options, 'data_field_2' ), 
				'options' => $dataFields,
				'title' => __( 'Second(Center) Data Field:', 'team-rosters' ),
				'desc'	=> __( 'Default: Hometown', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
			array( 	// Third/rightmost data field
				'type' => 'select-option', 
				'id' => 'data_field_3',
				'name'	=> 'mstw_tr_options[data_field_3]',
				'value' => mstw_tr_safe_ref( $options, 'data_field_3' ), 
				'options' => $dataFields,
				'title' => __( 'Third(Rightmost) Data Field:', 'team-rosters' ),
				'desc'	=> __( 'Default: Last School', 'team-rosters' ),
				'page' => $display_on_page,
				'section' => $section_id,
			),
		);
		
		mstw_tr_build_settings_screen( $arguments );
		
	} //End: mstw_tr_roster_table2_section_setup( )

	//-----------------------------------------------------------------	
	// 	Roster table settings section instructions	
	//	
	function mstw_tr_roster_table_inst( ) {
		//mstw_log_msg( 'mstw_tr_roster_table_inst:' );
	
		echo '<p>', esc_html__( 'These settings will apply to all the [mstw-tr-roster] shortcode tables, overriding the settings defaults. In most cases, these settings can be overridden by shortcode arguments.', 'team-rosters' ),'</p>';
		
	} //End: mstw_tr_roster_table_inst()

	function mstw_tr_roster_table_2_inst( ) {
		//mstw_log_msg( 'mstw_tr_roster_table_2_inst:' );	
	
		echo '<p>', esc_html__( 'These settings will apply to all the [mstw-tr-roster-2] shortcode tables, overriding the settings defaults. In most cases, these settings can be overridden by shortcode arguments.', 'team-rosters' ), '</p>';
		
	} //End: mstw_tr_roster_table_2_inst()